@@ -121,7 +121,7 @@ sub new {
 
     push @$main, q|.PHONY: all install clean uninstall help upload link|;
     
-    my $filelist = $self->make_filelist();
+    my $filelist = $self->make_filelist( LIBPATH );
 
     $makefile->{filelist} = $filelist;
 
@@ -140,13 +140,14 @@ sub new {
     $self->section_link( $main , $filelist );
 
     # -----------
-
     new_section $main => 'manifest';
+    add_st $main => q|$(NOECHO) $(ECHO) ".git" > MANIFEST.SKIP|;
+    add_st $main => q|$(NOECHO) $(ECHO) ".svn" >> MANIFEST.SKIP|;
+    add_st $main => q|$(NOECHO) $(ECHO) ".*.tar.gz" >> MANIFEST.SKIP|;
     add_st $main => q|$(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Manifest=mkmanifest -e 'mkmanifest'|;
-    add_st $main => q|$(NOECHO) $(TOUCH) MANIFEST.SKIP|;
 
-    new_section $main => 'dist';
-    add_st $main => q|$(TAR) $(TARFLAGS) $(DISTNAME).tar.gz $(TO_INST_VIMS) $(META_FILE) $(README)|;
+    new_section $main => 'dist' , qw(manifest);
+    add_st $main => q|$(TAR) $(TARFLAGS) $(DISTNAME).tar.gz $(TO_INST_VIMS) $(META_FILE) $(README) `cat MANIFEST`|;
 	add_noop_st $main;
 
     new_section $main => 'help';
@@ -157,6 +158,8 @@ sub new {
             . q| -e 'uninstall()' $(NAME)|;
 
     # XXX: prompt user to uninstall depedencies
+    new_section $main => 'reinstall' , qw(uninstall install);
+    add_noop_st $main;
 
     new_section $main => 'upload' , qw(dist);
     add_st $main => q|$(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Uploader=upload -e 'upload()' |
@@ -166,6 +169,14 @@ sub new {
     add_st $main      => q|$(MV) $(FIRST_MAKEFILE) $(MAKEFILE_OLD)|;
     add_st $main      => q|$(RM) *.tar.gz|;
 
+    new_section $main => 'bump';
+    add_st $main => q|$(NOECHO) $(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Installer=bump_version -e 'bump_version()' |;
+    add_st $main => q|sh -c 'vim-packager build'|;  # rebuild
+    add_st $main => q|sh -c 'make upload'|;
+
+    new_section $main => 'release' , qw(bump);
+    add_noop_st $main;
+
     $self->generate_makefile( [
             { meta   => \@meta_section },
             { config => \@config_section },
@@ -356,7 +367,6 @@ END
     print "DONE\n";
 }
 
-
 sub meta_section {
     my $self = shift;
     my $meta = shift;
@@ -433,6 +443,7 @@ sub file_section {
     my @to_install = keys %$filelist;
 
     add_macro \@section , VIMLIB => LIBPATH;
+
     add_macro \@section , VIMMETA => VIM::Packager::MetaReader::find_meta_file();
 
     add_macro \@section , TO_INST_VIMS => multi_line @to_install ;
@@ -455,6 +466,10 @@ sub file_section {
     return @section;
 }
 
+=head2 get_installed_pkgs
+
+=cut
+
 sub get_installed_pkgs {
     my ($self, $dir ) = @_;
 
@@ -478,6 +493,14 @@ sub get_installed_pkgs {
     return @pkg_record_files;
 }
 
+
+
+=head2 check_dependency
+
+pass meta object and check dependency.
+
+=cut
+
 sub check_dependency {
     my $self = shift;
     my $meta = shift;
@@ -557,6 +580,12 @@ sub check_dependency {
 
 
 
+=head2 init_vim_dir_macro
+
+init vim dir macro
+
+=cut
+
 sub init_vim_dir_macro {
     my $self = shift;
     my %dir_configs = ();
@@ -576,11 +605,24 @@ sub init_vim_dir_macro {
 }
 
 
+=head2 make_filelist
+
+if install_dirs is given , then we should record:
+
+    autoload/zzz.vim
+    plugin/xxx.vim
+
+if not , then we should find files from F<vimlib/>
+
+    TO_INSTALL=$(VIM_BASEDIR)/plugin/xxx.vim
+        \ $(VIM_BASEDIR)/autoload/zzz.vim
+
+=cut
+
 sub make_filelist {
-    my $self = shift;
+    my ( $self, $base_prefix ) = @_;
 
     my %install = ();
-    my $base_prefix = LIBPATH;
 
     # my $prefix = File::Spec->join($ENV{HOME} , '.vim');
     my $prefix = '$(VIM_BASEDIR)';
